<?php

define( 'RL_PREFIX', 'root-lite-' );

require_once __DIR__ . '/vendor/autoload.php';

function root_init_updates() {
    $checker = \Puc_v4_Factory::buildUpdateChecker(
        'https://api.wpshop.biz/wp-update-server/?action=get_metadata',
        __FILE__,
        'root-lite',
        12,
        'root-lite--check-update'
    );
    $checker->addQueryArgFilter( function ( $queryArgs ) {
        $queryArgs['slug'] = 'root-lite';

        return $queryArgs;
    } );
}
root_init_updates();

if ( ! function_exists( 'root_setup' ) ) :
/**
 * Theme setup
 */
function root_setup() {
	load_theme_textdomain( 'root-lite', get_template_directory() . '/languages' );

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );

    /*
     * Add new image size
     */
    $thumb_big_sizes  = apply_filters( 'root_thumb_big_sizes', array( 770, 330, true ) );
    $thumb_wide_sizes = apply_filters( 'root_thumb_wide_sizes', array( 330, 140, true ) );
    if ( function_exists( 'add_image_size' ) ) {
        add_image_size( RL_PREFIX . 'thumb-big', $thumb_big_sizes[0], $thumb_big_sizes[1], $thumb_big_sizes[2] );
        add_image_size( RL_PREFIX . 'thumb-wide', $thumb_wide_sizes[0], $thumb_wide_sizes[1], $thumb_wide_sizes[2] );
    }

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'top_menu'    => esc_html__( 'Top menu', 'root-lite' ),
		'header_menu' => esc_html__( 'Header menu', 'root-lite' ),
		'footer_menu' => esc_html__( 'Footer menu', 'root-lite' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'root_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'root_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function root_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'root_content_width', 700 ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
}
add_action( 'after_setup_theme', 'root_content_width', 0 );




/**
 * Register widget area.
 */
function root_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'root-lite' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'root-lite' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-header">',
		'after_title'   => '</div>',
	) );
}
add_action( 'widgets_init', 'root_widgets_init' );





/**
 * Enqueue scripts and styles.
 */
function root_scripts() {

    $theme = wp_get_theme();
    if ( $theme->parent() ) {
        $theme = $theme->parent();
    }

    $root_main_fonts            = root_get_option( 'typography_family' );
    $root_main_fonts_headers    = root_get_option( 'typography_headers_family' );

    global $root_fonts;
    if ( empty( $root_fonts ) ) $root_fonts = [];

    $fonts_style = array();
    foreach ( $root_fonts as $key => $val ) {
        $fonts_style[$key] = $val['url'];
    }

    if ( isset( $fonts_style[ $root_main_fonts ] ) ) {
        wp_enqueue_style('google-fonts', $fonts_style[ $root_main_fonts ], false);
    }

    if ( isset( $fonts_style[ $root_main_fonts_headers ] ) && $root_main_fonts != $root_main_fonts_headers ) {
        wp_enqueue_style('google-fonts-headers', $fonts_style[ $root_main_fonts_headers ], false);
    }

    $style_version = apply_filters( 'root_style_version', $theme->get( 'Version' ) );

	wp_enqueue_style(  'root-style',   get_template_directory_uri() . '/css/style.min.css', array(), $style_version );

	wp_enqueue_script( 'root-scripts', get_template_directory_uri() . '/js/scripts.js', array('jquery'), $style_version, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
function root_admin_scripts() {
    wp_enqueue_style( 'root-admin-style', get_template_directory_uri() . '/css/style.admin.css', array(), null );
}
add_action( 'wp_enqueue_scripts', 'root_scripts' );
add_action( 'admin_enqueue_scripts', 'root_admin_scripts' );


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


/**
 * Comments
 */
require get_template_directory() . '/inc/comments.php';


/**
 * Smiles
 */
require get_template_directory() . '/inc/smiles.php';


/**
 * Thumbnails
 */
require get_template_directory() . '/inc/thumbnails.php';


/**
 * Core
 */
require get_template_directory() . '/inc/core/core.php';






/********************************************************************
 * Editor styles
 *******************************************************************/
function root_add_editor_style() {
    add_editor_style( 'css/editor-styles.css' );
}
add_action( 'current_screen', 'root_add_editor_style' );



/********************************************************************
 * Excerpt
 *******************************************************************/
if ( ! function_exists( 'root_new_excerpt_length' ) ) {
    function root_new_excerpt_length( $length ) {
        if ( is_admin() ) {
            return $length;
        }

        return 28;
    }

    add_filter( 'excerpt_length', 'root_new_excerpt_length' );
}

if ( ! function_exists( 'root_change_excerpt_more' ) ) {
    function root_change_excerpt_more( $more ) {
        if ( is_admin() ) {
            return $more;
        }

        return '...';
    }

    add_filter( 'excerpt_more', 'root_change_excerpt_more' );
}



/********************************************************************
 * Breadcrumbs
 *******************************************************************/
/**
 * Remove last item from breadcrumbs SEO by YOAST
 * http://www.wpdiv.com/remove-post-title-yoast-seo-plugin-breadcrumb/
 */
function root_adjust_single_breadcrumb( $link_output ) {
    if ( strpos( $link_output, 'breadcrumb_last' ) !== false ) {
        $link_output = '';
    }

    return $link_output;
}
// theme feature for the plugin support
add_filter( 'wpseo_breadcrumb_single_link', 'root_adjust_single_breadcrumb' );



/********************************************************************
 * Microformat images
 *******************************************************************/
if ( ! function_exists('root_microformat_image') ):
    function root_microformat_image($content) {
        $pattern  = '/<img (.*?) width="(.*?)" height="(.*?)" (.*?)>/si';
        $replace = '<span itemprop="image" itemscope itemtype="https://schema.org/ImageObject"><img itemprop="url image" \\1 width="\\2" height="\\3" \\4/><meta itemprop="width" content="\\2"><meta itemprop="height" content="\\3"></span>';
        $content = preg_replace($pattern, $replace, $content);
        return $content;
    }
    add_filter('the_content', 'root_microformat_image', 999);
endif;




/**
 * Remove h2 from pagination and navigation
 */
function root_change_navigation_markup_template( $template, $class ) {
    $template = '
	<nav class="navigation %1$s" role="navigation">
		<div class="screen-reader-text">%2$s</div>
		<div class="nav-links">%3$s</div>
	</nav>';
    return $template;
};

add_filter( 'navigation_markup_template', 'root_change_navigation_markup_template', 10, 2 );








/**
 * Remove current link in menu
 *
 * @param $nav_menu
 * @param $args
 * @return mixed
 */
function root_remove_current_links_from_menu( $nav_menu, $args )
{
    preg_match_all('/<li(.+?)class="(.+?)current-menu-item(.+?)>(<a(.+?)>(.+?)<\/a>)/ui', $nav_menu, $matches);

    if ( isset($matches[4]) && !empty($matches[4]) && preg_match('/<a/ui', $matches[4][0]) ) {
        foreach ($matches[4] as $k => $v) {
            if ( ! is_paged() ) {
				$nav_menu = str_replace($v, '<span class="removed-link">' . $matches[6][$k] . '</span>', $nav_menu);
			}
        }
    }

    return $nav_menu;
}

add_filter( 'wp_nav_menu', 'root_remove_current_links_from_menu', PHP_INT_MAX, 2 );





function root_options_defaults() {
    $defaults = apply_filters( 'root_options_defaults', array(
        'header_padding_top'    => 0,
        'header_padding_bottom' => 0,
        'header_width'          => 'fixed',
        'header_inner_width'    => 'full',

        'navigation_main_width'         => 'fixed',
        'navigation_main_inner_width'   => 'full',

        'navigation_footer_width'       => 'fixed',
        'navigation_footer_inner_width' => 'full',

        'footer_width'          => 'fixed',
        'footer_inner_width'    => 'full',

        'skin'                  => 'no',
        'bg_pattern'            => 'no',

        'logotype_image'        => '',
        'header_bg'             => '',
        'header_bg_repeat'      => 'no-repeat',
        'header_bg_position'    => 'center center',

        'header_hide_title'     => 'no',

        'color_main'            => '#5a80b1',
        'color_link'            => '#428bca',
        'color_link_hover'      => '#e66212',
        'color_text'            => '#333333',
        'color_logo'            => '#5a80b1',
        'color_menu_bg'         => '#5a80b1',
        'color_menu'            => '#ffffff',

        'footer_copyright'      => '&copy; %year% ' . get_bloginfo( 'name' ),
        'footer_counters'       => '',
        'footer_text'           => '',

        'structure_home_posts'          => 'post-box',
        'structure_home_sidebar'        => 'right',
        'structure_home_h1'             => '',
        'structure_home_text'           => '',
        'structure_home_position'       => 'bottom',

        'structure_single_sidebar'          => 'right',
        'structure_single_thumb'            => 'yes',
        'structure_single_author'           => 'yes',
        'structure_single_date'             => 'yes',
        'structure_single_category'         => 'yes',
        'structure_single_social'           => 'yes',
        'structure_single_excerpt'          => 'yes',
        'structure_single_comments_count'   => 'yes',
        'structure_single_views'            => 'yes',
        'structure_single_tags'             => 'yes',
        'structure_single_social_bottom'    => 'yes',
        'structure_single_related'          => '6',
        'structure_single_comments'         => 'yes',

        'structure_page_sidebar'            => 'right',
        'structure_page_related'            => '6',
        'structure_page_comments'           => 'no',

        'structure_archive_posts'           => 'post-box',
        'structure_archive_sidebar'         => 'right',
        'structure_archive_description'     => 'top',

        'posts_related_show_thumbnail' => 'yes',
        'posts_related_show_excerpt' => 'yes',

        'structure_posts_tag'               => 'div',
        'structure_posts_author'            => 'yes',
        'structure_posts_date'              => 'yes',
        'structure_posts_category'          => 'yes',
        'structure_posts_excerpt'           => 'yes',
        'structure_posts_comments'          => 'yes',
        'structure_posts_views'             => 'yes',

        'typography_family'         => 'roboto',
        'typography_font_size'      => '16',
        'typography_line_height'    => '1.5',
        'typography_headers_family' => 'roboto',

        'structure_arrow'           => 'yes',
        'structure_arrow_bg'        => '#cccccc',
        'structure_arrow_color'     => '#ffffff',
        'structure_arrow_width'     => '50',
        'structure_arrow_height'    => '50',
        'structure_arrow_icon'      => '\f102',
        'structure_arrow_mob'       => 'no',

        'comments_text_before_submit'   => '',
        'comments_date'                 => 'yes',
        'comments_smiles'               => 'yes',
    ) );
    return $defaults;
}

function root_options() {
    $root_options = wp_parse_args(
        get_option( 'root_options', array() ),
        root_options_defaults()
    );

    return $root_options;
}

function root_get_option( $option ) {
    $root_options = root_options();

    return ( isset($root_options[$option]) ) ? $root_options[$option] : '' ;
}


/**
 * Site header classes
 */
function root_site_header_classes() {
    $option    = root_get_option( 'header_width' );
    $out_class = ( $option == 'fixed' ) ? 'container' : '';

    return apply_filters( 'root_site_header_classes', $out_class );
}

/**
 * Site header inner classes
 */
function root_site_header_inner_classes() {
    $option    = root_get_option( 'header_inner_width' );
    $out_class = ( $option == 'fixed' ) ? 'container' : '';

    return apply_filters( 'root_site_header_inner_classes', $out_class );
}

/**
 * Main navigation classes
 */
function root_navigation_main_classes() {
    $option    = root_get_option( 'navigation_main_width' );
    $out_class = ( $option == 'fixed' ) ? 'container' : '';

    return apply_filters( 'root_navigation_main_classes', $out_class );
}

/**
 * Main navigation inner classes
 */
function root_navigation_main_inner_classes() {
    $option    = root_get_option( 'navigation_main_inner_width' );
    $out_class = ( $option == 'fixed' ) ? 'container' : '';

    return apply_filters( 'root_navigation_main_inner_classes', $out_class );
}

function root_site_content_classes() {
    return apply_filters( 'root_site_content_classes', 'container' );
}

function root_site_footer_classes() {
    $option    = root_get_option( 'footer_width' );
    $out_class = ( $option == 'fixed' ) ? 'container' : '';

    $classes = apply_filters( 'root_site_footer_classes', $out_class );

    return $classes;
}

function root_site_footer_inner_classes() {
    $option    = root_get_option( 'footer_inner_width' );
    $out_class = ( $option == 'fixed' ) ? 'container' : '';

    $classes = apply_filters( 'root_site_footer_inner_classes', $out_class );

    return $classes;
}

function root_navigation_footer_classes() {
    $option    = root_get_option( 'navigation_footer_width' );
    $out_class = ( $option == 'fixed' ) ? 'container' : '';

    return apply_filters( 'root_navigation_footer_classes', $out_class );
}

function root_navigation_footer_inner_classes() {
    $option    = root_get_option( 'navigation_footer_inner_width' );
    $out_class = ( $option == 'fixed' ) ? 'container' : '';

    return apply_filters( 'root_navigation_footer_inner_classes', $out_class );
}

if ( ! function_exists( 'wp_body_open' ) ) { // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
	// phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
    function wp_body_open() { // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedFunctionFound
        do_action( 'wp_body_open' ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
    }
}
