<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<?php wp_head(); ?>
<?php echo root_get_option( 'code_head' ) ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#main"><?php esc_html_e( 'Skip to content', 'root-lite' ); ?></a>

    <?php do_action( 'root_before_header' ); ?>

	<header id="masthead" class="site-header <?php echo esc_attr( root_site_header_classes() ) ?>" itemscope itemtype="http://schema.org/WPHeader">
        <div class="site-header-inner <?php echo esc_attr( root_site_header_inner_classes() ) ?>">
		<div class="site-branding">

			<?php
			$root_logotype = root_get_option( 'logotype_image' );
			$logotype_alt = apply_filters( 'root_logotype_alt', get_bloginfo( 'name' ) );

			if ( ! empty( $root_logotype ) ) {
				if ( is_front_page() ) {
					if ( is_home() && is_paged()  ) {
						echo '<div class="site-logotype"><a href="'. esc_url( home_url( '/' ) ) .'"><img src="' . $root_logotype . '" alt="' . $logotype_alt . '"></a></div>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					} else {
						echo '<div class="site-logotype"><img src="' . $root_logotype . '" alt="' . $logotype_alt . '"></div>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					}
				} else {
					echo '<div class="site-logotype"><a href="'. esc_url( home_url( '/' ) ) .'"><img src="' . $root_logotype . '" alt="' . $logotype_alt . '"></a></div>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				}
			}
			?>

			<?php if ( root_get_option( 'header_hide_title' ) == 'no' ) { ?>
			<div class="site-branding-container">

                <?php
                    $root_structure_home_h1 = root_get_option( 'structure_home_h1' );
                    if ( ! $root_structure_home_h1 ) $root_structure_home_h1 = '';

                    $site_title_text = get_bloginfo( 'name' );
                    $site_title_tag = 'div';

                    if ( is_front_page() && is_home() ) {

                        if ( empty( $root_structure_home_h1 ) ) {
                            $site_title_tag = 'h1';
                        }

                        if ( is_paged() ) {
                            $site_title_text = '<a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html( get_bloginfo( 'name' ) ) . '</a>';
                        }

                    } else {
                        if ( ! is_front_page() ) {
                            $site_title_text = '<a href="' . esc_url( home_url('/') ) . '">' . esc_html( get_bloginfo('name') ) . '</a>';
                        }
                    }

                    // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                    echo '<'. $site_title_tag .' class="site-title">' . $site_title_text . '</'. $site_title_tag .'>';
                ?>

				<?php

				$description = get_bloginfo( 'description', 'display' );
				if ( $description || is_customize_preview() ) : ?>
					<p class="site-description"><?php echo esc_html( $description ); ?></p>
				<?php
				endif; ?>

			</div>
			<?php } ?>
		</div><!-- .site-branding -->

		<div class="top-menu">
			<?php
			if ( has_nav_menu( 'top_menu' ) ) {
				wp_nav_menu( array('theme_location' => 'top_menu', 'menu_id' => 'top_menu') );
			}
			?>
		</div>

        <div class="mob-hamburger"><span></span></div>
        </div><!--.site-header-inner-->
	</header><!-- #masthead -->

    <?php do_action( 'root_after_header' ); ?>

    <?php
    /**
     * Check menu exist, if no - add separator
     */
    if ( has_nav_menu( 'header_menu' ) ) { ?>

        <?php do_action( 'root_before_main_navigation' ); ?>

        <nav id="site-navigation" class="main-navigation <?php echo esc_attr( root_navigation_main_classes() ) ?>">
            <div class="main-navigation-inner <?php echo esc_attr( root_navigation_main_inner_classes() ) ?>">
                <?php wp_nav_menu( array('theme_location' => 'header_menu', 'menu_id' => 'header_menu') ) ?>
            </div><!--.main-navigation-inner-->
        </nav><!-- #site-navigation -->

        <?php do_action( 'root_after_main_navigation' ); ?>

    <?php } else { ?>

        <nav id="site-navigation" class="main-navigation" style="display: none;"><ul id="header_menu"></ul></nav>
        <div class="container header-separator"></div>

    <?php } ?>

    <?php do_action( 'root_before_site_content' ); ?>

	<div id="content" class="site-content <?php echo esc_attr( root_site_content_classes() ) ?>">
