<?php
/**
 * Template tags
 *
 * @package Root Lite
 */


// admin notices
add_action( 'admin_notices', 'root_lite_admin_notices' );
function root_lite_admin_notices() {

	$wpshop_admin_notices = get_option( 'wpshop_admin_notices', [] );

	$notices = [];
	if ( get_transient( 'wpshop_admin_notices_cache' ) ) {
		$notices = get_transient( 'wpshop_admin_notices_cache' );
	} else {
		$request = wp_remote_get( 'https://wpshop.tech/api/admin-notices.php' );
		if ( ! is_wp_error( $request ) ) {
			if ( wp_remote_retrieve_response_code( $request ) === 200 ) {
				$body = wp_remote_retrieve_body( $request );
				if ( ! empty( $body ) ) {
					$notices = json_decode( $body, true );
					set_transient( 'wpshop_admin_notices_cache', $notices, 3600 );
				}
			}
		}
	}

	if ( ! empty( $notices ) && is_array( $notices ) ) {
		foreach ( $notices as $notice_name => $notice ) {

			if ( isset( $wpshop_admin_notices[ $notice_name ] ) && $wpshop_admin_notices[ $notice_name ]['dismiss'] ) {
				continue;
			}

			$is_dismissible = ( $notice['dismissible'] ) ? ' is-dismissible' : '';

			if ( ! empty( $notice['html'] ) ) {
				echo '<div class="notice wpshop-notice notice-' . $notice['type'] . $is_dismissible . '" data-name="' . $notice_name . '">'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo $notice['html']; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo '</div>';
			}
		}
	}
}


add_action( 'admin_print_footer_scripts', 'root_lite_admin_print_footer_scripts' );
function root_lite_admin_print_footer_scripts(){
	?>
	<script type="text/javascript">
        jQuery(document).ready(function($){
            jQuery( document ).on( 'click', '.wpshop-notice .notice-dismiss', function() {
                var $notice = $(this).parents('.wpshop-notice');
                jQuery.post( ajaxurl, {
                    action: 'wpshop_dismiss_notice',
                    name: $notice.data('name'),
                });
            })
        });
	</script>
	<?php
}

add_action( 'wp_ajax_wpshop_dismiss_notice', 'root_ajax_wpshop_dismiss_notice' );
function root_ajax_wpshop_dismiss_notice() {
	$wpshop_admin_notices = get_option( 'wpshop_admin_notices', [] );
	if ( empty( $wpshop_admin_notices ) ) $wpshop_admin_notices = [];

	$notice_name = '';
	if ( ! empty( $_POST['name'] ) ) $notice_name = wp_unslash( $_POST['name'] ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized

	$wpshop_admin_notices[$notice_name] = [
		'dismiss' => true,
		'dismiss_date' => time(),
	];

	update_option( 'wpshop_admin_notices', $wpshop_admin_notices );

	wp_die();
}







// remove archive prefixes
add_filter( 'get_the_archive_title_prefix', '__return_empty_string' );



// Добавляет ссылку в админ бар
if ( get_locale() == 'ru_RU' ) {
	add_action( 'admin_bar_menu', 'root_lite_admin_bar_menu', 99999 );
}
function root_lite_admin_bar_menu( $wp_admin_bar ){

	$home_url     = home_url();
	$home_url     = parse_url( $home_url, PHP_URL_HOST );

	$wp_admin_bar->add_menu( array(
		'id'    => 'wpshop-root-lite',
		'title' => '🔺 Root Lite',
		'href'  => 'https://wpshop.ru/?utm_source=root-lite&utm_medium=admin-bar&utm_campaign=' . $home_url
	) );

	$wp_admin_bar->add_menu( array(
		'parent' => 'wpshop-root-lite',
		'id'     => 'wpshop-root-lite-updates',
		'title'  => 'Обновления',
		'href'   => 'https://support.wpshop.ru/forum/root-lite/?utm_source=root-lite&utm_medium=admin-bar&utm_campaign=' . $home_url,
	) );

	$wp_admin_bar->add_menu( array(
		'parent' => 'wpshop-root-lite',
		'id'     => 'wpshop-root-lite-support',
		'title'  => 'Поддержка',
		'href'   => 'https://t.me/wpcommunity',
	) );

	$wp_admin_bar->add_menu( array(
		'parent' => 'wpshop-root-lite',
		'id'     => 'wpshop-root-lite-premium',
		'title'  => 'Root Premium',
		'href'   => 'https://wpshop.ru/themes/root?utm_source=root-lite&utm_medium=admin-bar&utm_campaign=' . $home_url
	) );

	$wp_admin_bar->add_menu( array(
		'parent' => 'wpshop-root-lite',
		'id'     => 'wpshop-root-lite-clearfy',
		'title'  => 'Clearfy Pro',
		'href'   => 'https://wpshop.ru/plugins/clearfy?utm_source=root-lite&utm_medium=admin-bar&utm_campaign=' . $home_url
	) );
}


/**
 * Output category with Yoast support
 *
 * @package Root
 * @author Aleynikov Sergey
 * @url http://wpshop.ru/
 */
if ( ! function_exists( 'root_category' ) ) {

	/**
	 * @param bool $post
	 * @param string $classes
	 * @param bool $micro
	 * @param bool $link
	 * @return bool|string
	 */
	function root_category( $post = false, $classes = '', $micro = true, $link = true ) {

		if ( ! $post = get_post( $post ) )
			return false;

		$classes_out = '';
		if ( ! empty( $classes ) ) $classes_out = ' class="' . $classes . '"';

		$category = get_the_category( $post->ID );
		$cat_id = $category[0]->cat_ID;

		if ( class_exists( 'WPSEO_Primary_Term' ) ) {
			$primary_cat = new WPSEO_Primary_Term('category', $post->ID);
			$primary_cat = $primary_cat->get_primary_term();
			if ( $primary_cat ) {
				$cat_id = $primary_cat;
			}
		}

		if ( $micro ) {
            $micro_out = ' itemprop="articleSection"';
        } else {
            $micro_out = '';
        }

		if ( $link ) {
			return '<a href="' . get_category_link($cat_id) . '"' . $micro_out . $classes_out . '>' . get_cat_name($cat_id) . '</a>';
		} else {
			return '<span' . $micro_out . $classes_out . '>' . get_cat_name($cat_id) . '</span>';
		}

	}

}


/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function root_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'root_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'root_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so root_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so root_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in root_categorized_blog.
 */
function root_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'root_categories' );
}
add_action( 'edit_category', 'root_category_transient_flusher' );
add_action( 'save_post',     'root_category_transient_flusher' );
